==========
References
==========

This section contains reference materials for Ironic, including API documentation, CLI tools, configuration details, and more.

Drivers, Hardware Types, and Hardware Interfaces
------------------------------------------------
:doc:`Drivers, Hardware Types, and Hardware Interfaces </admin/index>`

Configuration Reference
-----------------------
:doc:`Configuration Reference </configuration/index>`

API Reference
-------------
`API Reference <https://docs.openstack.org/api-ref/baremetal/>`_

CLI References
--------------
- `Ironic CLI <https://docs.openstack.org/python-ironicclient/queens/cli/ironic_client.html>`_
- :doc:`ironic-dbsync </cli/ironic-dbsync>`
- `ironic-status <https://docs.openstack.org/python-ironicclient/queens/cli/ironic_client.html>`_
